diff --git a/mpsd-software-environment.py b/mpsd-software-environment.py
index 7575d3f3639d843732e1de2d4f2a19a64d431b4e..73cce3879863fa94b54aa6bd9d999be432c37ac2 100755
--- a/mpsd-software-environment.py
+++ b/mpsd-software-environment.py
@@ -254,7 +254,7 @@ def install_environment(
                     cache when installing toolchains. Defaults to False.
 
     Raises:
         Exception: If a requested toolchain is not available in the specified release.
 
     Returns:
         None
@@ -292,7 +292,7 @@ def install_environment(
 
     for toolchain in toolchains:
         if toolchain not in available_toolchains:
-            raise Exception(
+            raise ValueError(
                 f"Toolchain '{toolchain}' is not available in release {mpsd_release}."
             )
@@ -254,7 +254,7 @@ def install_environment(
 
     Raises:
-        Exception: If a requested toolchain is not available in the specified release.
+        ValueError: If a requested toolchain is not available in the specified release.
 
     Returns: